<template>
  <div>
    <el-dialog
      width="80%"
      :title="titleUp + '单位信息'"
      :visible.sync="showFormDiaUp"
      :before-close="handleClose"
    >
      <el-form
        ref="formInfo"
        :rules="rules"
        :model="params"
        label-width="120px"
      >
        <el-collapse accordion v-model="activeCollapse" class="form-collapse">
          <el-collapse-item name="1">
            <template slot="title">
              <span class="collapse-title">
                <i class="collapse-title-icon el-icon-info"></i>
                人员基本信息
              </span>
            </template>
            <el-row>
              <el-col :span="8">
                <el-form-item prop="companyName" label="单位名称">
                  <el-input
                    placeholder="请输入单位名称"
                    v-model="params.companyName"
                  ></el-input>
                </el-form-item>
              </el-col>
              <el-col :span="8">
                <el-form-item prop="companyShortName" label="单位简称">
                  <el-input
                    placeholder="请输入单位简称"
                    v-model="params.companyShortName"
                  ></el-input>
                </el-form-item>
              </el-col>
              <el-col :span="8">
                <el-form-item prop="companyCode" label="单位编码">
                  <el-input
                    placeholder="请输入单位编码"
                    v-model="params.companyCode"
                  ></el-input>
                </el-form-item>
              </el-col>
            </el-row>
            <el-row>
              <el-col :span="16">
                <el-form-item
                  prop="companyTypeShow"
                  label="单位类型"
                  class="company-type"
                >
                  <el-checkbox-group
                    v-model="params.companyTypeShow"
                    @change="changeType"
                  >
                    <el-checkbox
                      v-for="item in companyType"
                      :key="item.value"
                      :label="item.value"
                    >{{ item.name }}
                    </el-checkbox
                    >
                  </el-checkbox-group>
                </el-form-item>
              </el-col>
            </el-row>
            <el-row>
              <el-col :span="8">
                <el-form-item prop="companyMan" label="联系人">
                  <el-input
                    placeholder="请输入联系人"
                    v-model="params.companyMan"
                  ></el-input>
                </el-form-item>
              </el-col>
              <el-col :span="8">
                <el-form-item label="联系电话" prop="companyTel">
                  <el-input
                    placeholder="请输入联系电话"
                    v-model="params.companyTel"
                  ></el-input>
                </el-form-item>
              </el-col>
              <el-col :span="8">
                <el-form-item prop="companyMail" label="单位邮箱">
                  <el-input
                    placeholder="请输入单位邮箱"
                    v-model="params.companyMail"
                  ></el-input>
                </el-form-item>
              </el-col>
            </el-row>
            <el-row>
              <el-col :span="8">
                <el-form-item prop="companyFax" label="单位传真">
                  <el-input
                    placeholder="请输入单位传真"
                    v-model="params.companyFax"
                  ></el-input>
                </el-form-item>
              </el-col>
              <el-col :span="16">
                <el-form-item label="单位地址" prop="companyAddress">
                  <el-input
                    type="textarea"
                    :autosize="{minRows: 1, maxRows: 1}"
                    placeholder="请输入单位地址"
                    v-model="params.companyAddress"
                  >
                  </el-input>
                </el-form-item>
              </el-col>
            </el-row>

            <el-form-item label="备注" prop="memo">
              <el-input
                type="textarea"
                :autosize="{minRows: 3, maxRows: 4}"
                placeholder="请输入备注内容"
                v-model="params.memo"
              >
              </el-input>
            </el-form-item>
          </el-collapse-item>
        </el-collapse>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="handleSave">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import userManage from '@/api/device/userManage.js'
import utils from '@/hotent-ui-util.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import resourceManage from '@/api/device/resourceManage.js'

export default {
  name: 'FormDialog',
  props: {
    showFormDiaUp: {
      type: Boolean,
      default: false
    },
    titleUp: {
      type: String,
      default: ''
    },
    pId: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      params: {
        companyAddress: '',
        companyCode: '',
        companyFax: '',
        companyMail: '',
        companyMan: '',
        companyName: '',
        companyShortName: '',
        companyTel: '',
        companyTypeShow: ['1'],
        companyType: '',
        memo: ''
      },
      activeCollapse: '1',
      companyType: [], //单位类型
      rules: {
        companyName: [
          {
            required: true,
            message: '请输入单位名称',
            trigger: 'blur'
          }
        ],
        companyShortName: [
          {
            required: true,
            message: '请输入单位简称',
            trigger: 'blur'
          }
        ],
        companyCode: [
          {
            required: true,
            message: '请输入单位编码',
            trigger: 'blur'
          }
        ],
        companyTypeShow: [
          {
            required: true,
            message: '请选择单位类型',
            trigger: 'blur'
          }
        ]
      }
    }
  },
  created() {
    this.companyType = dictUtils.getDictItemsFromCache('dwlx')
    this.getDetailInfo()
  },
  methods: {
    changeType() {
      this.$forceUpdate()
    },
    // 根据ID查询
    getDetailInfo() {
      userManage.UnitInfoDetail(this.pId).then(res => {
        this.params = res
        this.params.companyTypeShow = this.params.companyType
          ? this.params.companyType.split(',')
          : ['1']
      })
    },
    handleClose() {
      this.params = {
        companyAddress: '',
        companyCode: '',
        companyFax: '',
        companyMail: '',
        companyMan: '',
        companyName: '',
        companyShortName: '',
        companyTel: '',
        companyTypeShow: ['1'],
        companyType: '',
        memo: ''
      }
      this.activeCollapse = '1'
      this.$emit('closeFormDiaoUp')
      this.$emit('refList')
    },
    handleSave(e) {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          if (this.titleUp === '修改') {
            let tempData = utils.deepClone(this.params)
            tempData.companyType = tempData.companyTypeShow.length
              ? tempData.companyTypeShow.join(',')
              : ''
            delete tempData.companyTypeShow
            resourceManage.editUnit(tempData, response => {
              if (response.state) {
                this.$notify({
                  type: 'success',
                  message: '修改成功',
                  duration: 2000
                })
                this.$emit('closeFormDiaoUp')
                this.$emit('refList')
              } else {
                this.$message.success(response.message)
              }
            })
          }
        } else {
          return false
        }
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.company-type ::v-deep .el-checkbox-group {
  height: initial !important;
}
</style>
